@@ -18,89 +18,90 @@ use vars qw($system $time
 $system = new Test::C2FIT::eg::music::Simulator();
 $time = time(); # 10000;		#HACK start with a fixed time()
 
-$nextSearchComplete	= 0;
-$nextPlayStarted	= 0;
-$nextPlayComplete	= 0;
+$nextSearchComplete = 0;
+$nextPlayStarted = 0;
+$nextPlayComplete = 0;
 
-sub new
-{
-	my $pkg = shift;
-	return bless { @_ }, $pkg;
+sub new {
+    my $pkg = shift;
+
+    return bless { @_ }, $pkg;
 }
 
-sub nextEvent
-{
-	my $self = shift;
-	my($bound) = shift;
+sub nextEvent {
+    my $self = shift;
+    my($bound) = shift;
 
-	my $result = $bound;
-	$result = sooner($result, $nextSearchComplete);
-	$result = sooner($result, $nextPlayStarted);
-	$result = sooner($result, $nextPlayComplete);
-	return $result;
+    my $result = $bound;
+    $result = sooner($result, $nextSearchComplete);
+    $result = sooner($result, $nextPlayStarted);
+    $result = sooner($result, $nextPlayComplete);
+    return $result;
 }
 
-sub sooner
-{
-	my($soon, $event) = @_;
-	return ($event > $time and $event < $soon) ? $event : $soon;
+sub sooner {
+    my($soon, $event) = @_;
+
+    return ($event > $time && $event < $soon) ? $event : $soon;
 }
 
-sub perform
-{
-	my $self = shift;
-	Test::C2FIT::eg::music::MusicLibrary::searchComplete() if $time == $nextSearchComplete;
-	Test::C2FIT::eg::music::MusicPlayer::playStarted()     if $time == $nextPlayStarted;
-	Test::C2FIT::eg::music::MusicPlayer::playComplete()    if $time == $nextPlayComplete;
+sub perform {
+    my $self = shift;
+
+    Test::C2FIT::eg::music::MusicLibrary::searchComplete() if $time == $nextSearchComplete;
+    Test::C2FIT::eg::music::MusicPlayer::playStarted()     if $time == $nextPlayStarted;
+    Test::C2FIT::eg::music::MusicPlayer::playComplete()    if $time == $nextPlayComplete;
 }
 
-sub advance
-{
-	my $self = shift;
-	my($future) = @_;
-	while ( $time < $future )
-	{
-		$time = $self->nextEvent($future);
-		$self->perform();
+sub advance {
+    my $self = shift;
+    my($future) = @_;
+
+    #DEBUG print "advancing: $future ", (caller(1))[3], "\n";
+
+    while ( $time < $future ) {
+	$time = $self->nextEvent($future);
+	$self->perform();
     }
 }
 
-sub schedule
-{
+sub schedule {
 	my $self = shift;
-	my($seconds) = @_;
-	return $time + $seconds;
+    my($seconds) = @_;
+    return $time + ($self->_round($seconds));
 }
 
-sub delay
-{
-	my $self = shift;
-	my($seconds) = @_;
-	$self->advance($self->schedule($seconds));
+sub delay {
+    my $self = shift;
+    my($seconds) = @_;
+
+    $seconds = $self->_round($seconds);
+
+    $self->advance($self->schedule($seconds));
 }
 
-sub waitSearchComplete
-{
-	my $self = shift;
-	$self->advance($nextSearchComplete);
+sub waitSearchComplete {
+    my $self = shift;
+
+    $self->advance($nextSearchComplete);
 }
 
-sub waitPlayStarted
-{
-	my $self = shift;
-	$self->advance($nextPlayStarted);
+sub waitPlayStarted {
+    my $self = shift;
+
+    $self->advance($nextPlayStarted);
 }
 
-sub waitPlayComplete
-{
-	my $self = shift;
-	$self->advance($nextPlayComplete);
+sub waitPlayComplete {
+    my $self = shift;
+
+    $self->advance($nextPlayComplete);
 }
 
-sub failLoadJam
-{
-	my $self = shift;
-	$Test::C2FIT::ActionFixture::actor = new Test::C2FIT::eg::music::Dialog("load jamed", $Test::C2FIT::ActionFixture::actor);
+sub failLoadJam {
+    my $self = shift;
+
+    $Test::C2FIT::ActionFixture::actor = new Test::C2FIT::eg::music::Dialog("load jamed", $Test::C2FIT::ActionFixture::actor);
 }
 
 sub _round
@@ -108,10 +109,15 @@ sub _round
 	my $self = shift;
 	my $seconds = shift;
 
+	return int($seconds + 0.5);
+
 	my $roundDown = int($seconds);
 
 	my $fractionalPart = $seconds - $roundDown;
 
+warn "Seconds: $seconds, Down: $roundDown, Fract: $fractionalPart";
+
+	return 1;
 	return ($fractionalPart >= .5 ? $seconds + 1 : $seconds);
 
 }
